@@ -2,7 +2,7 @@
 #  as Perl itself)
 #
 #  (C) Tom Molesworth 2011,
-#      Paul Evans, 2011-2014 -- leonerd@leonerd.org.uk
+#      Paul Evans, 2011-2015 -- leonerd@leonerd.org.uk
 
 package Tickit::Widget::Tabbed;
 
@@ -21,7 +21,7 @@ use List::Util qw(max);
 
 use Tickit::Widget::Tabbed::Ribbon;
 
-our $VERSION = '0.016';
+our $VERSION = '0.017';
 
 =head1 NAME
 
@@ -95,12 +95,6 @@ use constant WIDGET_PEN_FROM_STYLE => 1;
 sub TAB_CLASS { shift->{tab_class} || "Tickit::Widget::Tabbed::Tab" }
 sub RIBBON_CLASS { shift->{ribbon_class} || "Tickit::Widget::Tabbed::Ribbon" }
 
-use constant CLEAR_BEFORE_RENDER => 0;
-
-# Don't need to implement this as rendering is done by the child or the tab
-# window using its expose event
-sub render_to_rb { }
-
 =head2 new
 
 Instantiate a new tabbed window.
@@ -449,12 +443,20 @@ sub on_key {
         }
         if($str =~ m/^M-(\d)$/ ) {
                 my $index = $1 - 1;
-                $self->activate_tab( $index ) if $index <= $self->{ribbon}->tabs;
+                $self->activate_tab( $index ) if $index < $self->{ribbon}->tabs;
                 return 1;
         }
         return 0;
 }
 
+sub render_to_rb {
+        my $self = shift;
+        my ( $rb, $rect ) = @_;
+
+        # Just clear the child area if we have nothing better to do
+        $rb->eraserect( $rect );
+}
+
 package Tickit::Widget::Tabbed::Tab;
 
 use 5.010; # for //= operator
