@@ -1,7 +1,7 @@
 #  You may distribute under the terms of the Artistic License (the same terms
 #  as Perl itself)
 #
-#  (C) Paul Evans, 2011-2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2011-2015 -- leonerd@leonerd.org.uk
 
 package Tickit::Widget::Tabbed::Ribbon;
 
@@ -11,7 +11,7 @@ use warnings;
 use base qw( Tickit::Widget );
 Tickit::Window->VERSION( '0.42' );
 
-our $VERSION = '0.016';
+our $VERSION = '0.017';
 
 use Scalar::Util qw( weaken );
 use Tickit::Utils qw( textwidth );
@@ -87,8 +87,6 @@ or
 
 =cut
 
-use constant CLEAR_BEFORE_RENDER => 0;
-
 sub new_for_orientation {
         my $class = shift;
         my ( $orientation, @args ) = @_;
@@ -221,7 +219,7 @@ sub remove_tab {
                         $self->active_tab->_activate;
                 }
                 else {
-                        $self->{tabbed}->window->clear;
+                        $self->{tabbed}->window->expose;
                 }
         }
 
